@@ -1,7 +1,8 @@
-# Standard library modules.
+from pathlib import Path
 
 from autograde.helpers import assert_equal, assert_iter_eqal, assert_is, assert_isclose, \
     assert_raises
 from autograde.notebook_test import NotebookTest
 
-__version__ = '0.2.2'
+__version__ = '0.2.3'
+__ag_root__ = Path(__file__).parent.parent.absolute()
